@@ -6,7 +6,7 @@
 #
 # FYI,
 #
-# I wrote a simple text file to PDF converter that uses PDF::API2::Lite.
+# I wrote a simple text file to PDF converter that uses PDF::API3::Compat::API2::Lite.
 # It isn't full-featured by any stretch but it does illustrate one of the
 # many uses of this cool module.  I'm submitting it here for your perusal.
 # If you think of any useful things to add to it please let me know.
@@ -15,12 +15,12 @@
 #
 # Thanks!  (Sorry about the long comments that wrap around to the next
 # line...)
-#
+# 
 # -MC
 #
 use strict;
 use warnings;
-use PDF::API2::Lite;
+use PDF::API3::Compat::API2::Lite;
 use Getopt::Long;
 use File::Basename;
 
@@ -40,7 +40,7 @@ my $layout;           	# portrait or landscape; default = portrait
 my $landscape;          # landscape cmd line flag
 my $fontsize;           # font size; default = 7.25
 my $bold;             	# set to 1 for bold on; default = 0;
-my $spacing;          	# text spacing ($pdf->textleading); default = 8
+my $spacing;          	# text spacing ($pdf->textlead); default = 8
 
 # other variables
 my @FILES;            	# list of input files, in case of glob
@@ -177,7 +177,7 @@ foreach $file ( @FILES ) {
   		$outfile = $destpath . $name . $suf . '.pdf';
   	} # if suffix is '.txt' or '.txt2pdf'
 
-	$pdf = PDF::API2::Lite->new;
+	$pdf = PDF::API3::Compat::API2::Lite->new;
 
   	&newpage;      # create first page in PDF document
 
@@ -210,7 +210,7 @@ sub newpage() {
   	else {$font = $pdf->corefont('Courier');}
 
   	$pdf->textstart;
-  	$pdf->textleading($spacing);
+  	$pdf->textlead($spacing);
   	$pdf->transform(-translate => [$left,$top]);
   	$pdf->textfont($font,$fontsize);
   	$linecount = 1;
@@ -246,9 +246,9 @@ Options:
 
 
   Special thanks to Alfred Reibenschuh for such a cool Perl module!
-  Also, many thanks to the PDF::API2 community for such great ideas.
+  Also, many thanks to the PDF::API3::Compat::API2 community for such great ideas.
 
 END_OF_USAGE
 }
 
-__END__
+__END__
\ No newline at end of file
